---
title: '세금계산서 역발행 기능을 이용하려면, 제휴사에 가입해야 하나요? '
category: 자주 묻는 질문 (일반 문의) > 파트너정산자동화 > 파트너정산자동화
seo:
  title: '세금계산서 제휴사 [팝빌] 자동 가입 이메일 안내 '
  description: >-
    포트원의 세금계산서 역발행 기능은 공급자와 공급받는자 모두 제휴사 [팝빌]에 회원가입을 완료해야 이용할 수 있습니다. 포트원 서비스
    내에서 [국세청 연동] 시 제휴사 팝빌에 자동으로 가입되며, 가입 완료 시 회원가입 이메일이 전송됩니다. 
tags:
  - 세금계산서 역발행
  - 정보보안
pgCompanies:
  - 공통
searchTags:
  - 개인정보위수탁
  - 정보보안
  - 개인정보처리방침
  - 파트너정산자동화
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="제휴사 사이트에 별도로 회원가입을 하지 않아도 자동으로 가입 처리가 진행됩니다. 
가입 즉시 제휴사 회원가입 이메일이 발송됩니다. " title="" />

### 세금계산서 역발행이란?

- 세금계산서 발행 주체인 \[공급자]가 아니라, \[공급받는자]가 공급자 대신 세금계산서를 작성하여 \[공급자]에 발행 요청하는 기능입니다.
- 플랫폼사가 파트너에게 지급할 정산대금 정보를 정확히 세금계산서 작성 시 기입하고, 해당 내용을 바탕으로 공급자는 이메일을 수취하여 승인할 수 있는 구조이기 때문에 공급받는자와 공급자의 소통 비용을 줄이고 빠르고 효율적으로 세금계산서를 발행할 수 있도록 도울 수 있습니다.

### 제휴사 회원가입이 필요한가요?

- 포트원의 세금계산서 역발행 기능은 공급자와 공급받는자 모두 제휴사에 회원가입을 완료해야 이용할 수 있습니다.
- 다만 포트원 서비스 내에서 \[국세청 연동] 시 제휴사에 자동으로 가입되며, 가입 완료 시 회원가입 이메일이 전송됩니다.

### 어떤 제휴사와 연동되어 있나요?

- 파트너 정산 자동화 서비스의 \[세금계산서 역발행] 기능을 제공하는 제휴사는 (주)링크허브이며, 서비스명은 \[팝빌]입니다.
- 세금계산서 기능을 이용하려면 공급자와 공급받는자 모두 올바른 사업자/담당자 정보를 완료해야하며, 포트원 파트너정산 서비스를 통해서 \[팝빌] 서비스에 가입 연동되어야 합니다.

### 서비스 이용을 위해서 제휴사에 가입해야 할까요?

- 아니오, 포트원은 팝빌 서비스 연동을 API를 통해서 진행하고 있습니다.
- 따라서 공급자와 공급받는자가 팝빌 서비스에 스스로 회원가입을 할 필요가 없고, \
  포트원 서비스 내의 \[국세청 연동] 을 완료하면 자동으로 회원가입이 완료됩니다.
- 팝빌 서비스에 회원가입이 완료되는 즉시, 입력한 담당자 이메일로 팝빌 회원가입 완료 이메일이 발송됩니다.

### 개인정보 처리에는 문제가 없나요?

- 파트너 정산 자동화 서비스의 \[송금대행 일괄지급], \[세금계산서 역발행] 등의 기능을 제공하기 위해 주식회사 코리아 포트원은 등록된 파트너의 개인정보를 제휴사에 (재)위탁하고 있습니다.
- (주)코리아포트원의 개인정보 처리방침은 [이 링크](https://portone.notion.site/f756e6b1a20d42e1af4dc887c9f8f420)를 참고해 주세요.

### 개인정보 처리방침, 우리 회사는 어떻게 준비해야 할까요?

<Callout content="개인정보 처리방침, 어렵지 않아요. 아래 내용을 참고하여 작성해주세요.
" />

- 고객사는 서비스를 이용하기 위해 정산 대상자 \[파트너] 에게 개인정보 처리방침을 안내할 의무가 있습니다. 개인정보 위탁 및 재위탁에 대한 내용을 작성하여 파트너에게 안내해 주세요.
- 개인정보 처리방침 작성 가이드는 [이 링크](https://help.portone.io/content/platform_infosec "파트너정산 고객사 개인정보처리방침 작성 가이드 ")를 참고해 주세요.

### 추가 질문이 있으시다면?

아래 연락처로 언제든지 편히 문의해주세요.

<Callout content="기술 문의 지원 이메일
b2b.support@portone.io" />

###
